@@ -1,6 +1,6 @@
 
 from .initialize import initialize
-from .record     import *
+from .records    import *
 
 import pyaas
 
